@@ -54,10 +54,12 @@ def get_site_packages_directory():
 def show_help():
     """How to call the initialization program"""
     site_package_directory = get_site_packages_directory()
-    source_directory = '{}/pygit/main.py'.format(site_package_directory)
+    source_directory_1 = '{}/pygit/main.py'.format(site_package_directory)
+    source_directory_2 = '{}/python_git-3.8-py3.6.egg/pygit/main.py'.format(site_package_directory)
     print('\n\nTo initialize pygit, run')
-    print('python ', source_directory)
-    print('run \npython ', source_directory, ' -h', '\nfor help')
+    print('\tpython ', source_directory_1, 'OR')
+    print('\tpython ', source_directory_2)
+    print("Include the -h flag for help")
     return
 
 def clear_screen():
